# abstractTrade-simpleTrade

This project is responsible to hold the abstraction for the flowing class and ensure they will
work and have the same structure on other projects.

- Initialization
- Rates
- Tick
- Timeframe
- Trade
